/****************************************************************************
** Meta object code from reading C++ file 'keyinfodialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kgpg-17.12.3/keyinfodialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keyinfodialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KgpgTrustLabel_t {
    QByteArrayData data[1];
    char stringdata0[15];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KgpgTrustLabel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KgpgTrustLabel_t qt_meta_stringdata_KgpgTrustLabel = {
    {
QT_MOC_LITERAL(0, 0, 14) // "KgpgTrustLabel"

    },
    "KgpgTrustLabel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KgpgTrustLabel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KgpgTrustLabel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KgpgTrustLabel::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KgpgTrustLabel.data,
      qt_meta_data_KgpgTrustLabel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KgpgTrustLabel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KgpgTrustLabel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KgpgTrustLabel.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KgpgTrustLabel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_KgpgKeyInfo_t {
    QByteArrayData data[19];
    char stringdata0[215];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KgpgKeyInfo_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KgpgKeyInfo_t qt_meta_stringdata_KgpgKeyInfo = {
    {
QT_MOC_LITERAL(0, 0, 11), // "KgpgKeyInfo"
QT_MOC_LITERAL(1, 12, 15), // "keyNeedsRefresh"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 12), // "KGpgKeyNode*"
QT_MOC_LITERAL(4, 42, 4), // "node"
QT_MOC_LITERAL(5, 47, 11), // "slotOpenUrl"
QT_MOC_LITERAL(6, 59, 3), // "url"
QT_MOC_LITERAL(7, 63, 14), // "slotChangeDate"
QT_MOC_LITERAL(8, 78, 14), // "slotDisableKey"
QT_MOC_LITERAL(9, 93, 4), // "ison"
QT_MOC_LITERAL(10, 98, 14), // "slotChangePass"
QT_MOC_LITERAL(11, 113, 23), // "slotInfoPasswordChanged"
QT_MOC_LITERAL(12, 137, 6), // "result"
QT_MOC_LITERAL(13, 144, 15), // "slotChangeTrust"
QT_MOC_LITERAL(14, 160, 8), // "newtrust"
QT_MOC_LITERAL(15, 169, 13), // "slotLoadPhoto"
QT_MOC_LITERAL(16, 183, 3), // "uid"
QT_MOC_LITERAL(17, 187, 11), // "slotApplied"
QT_MOC_LITERAL(18, 199, 15) // "slotKeyExpanded"

    },
    "KgpgKeyInfo\0keyNeedsRefresh\0\0KGpgKeyNode*\0"
    "node\0slotOpenUrl\0url\0slotChangeDate\0"
    "slotDisableKey\0ison\0slotChangePass\0"
    "slotInfoPasswordChanged\0result\0"
    "slotChangeTrust\0newtrust\0slotLoadPhoto\0"
    "uid\0slotApplied\0slotKeyExpanded"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KgpgKeyInfo[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,   67,    2, 0x08 /* Private */,
       7,    0,   70,    2, 0x08 /* Private */,
       8,    1,   71,    2, 0x08 /* Private */,
      10,    0,   74,    2, 0x08 /* Private */,
      11,    1,   75,    2, 0x08 /* Private */,
      13,    1,   78,    2, 0x08 /* Private */,
      15,    1,   81,    2, 0x08 /* Private */,
      17,    1,   84,    2, 0x08 /* Private */,
      18,    0,   87,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void, QMetaType::QString,   16,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void,

       0        // eod
};

void KgpgKeyInfo::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KgpgKeyInfo *_t = static_cast<KgpgKeyInfo *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->keyNeedsRefresh((*reinterpret_cast< KGpgKeyNode*(*)>(_a[1]))); break;
        case 1: _t->slotOpenUrl((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->slotChangeDate(); break;
        case 3: _t->slotDisableKey((*reinterpret_cast< const bool(*)>(_a[1]))); break;
        case 4: _t->slotChangePass(); break;
        case 5: _t->slotInfoPasswordChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->slotChangeTrust((*reinterpret_cast< const int(*)>(_a[1]))); break;
        case 7: _t->slotLoadPhoto((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->slotApplied((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->slotKeyExpanded(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KgpgKeyInfo::*_t)(KGpgKeyNode * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KgpgKeyInfo::keyNeedsRefresh)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KgpgKeyInfo::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_KgpgKeyInfo.data,
      qt_meta_data_KgpgKeyInfo,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KgpgKeyInfo::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KgpgKeyInfo::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KgpgKeyInfo.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::kgpgKeyInfo"))
        return static_cast< Ui::kgpgKeyInfo*>(this);
    return QDialog::qt_metacast(_clname);
}

int KgpgKeyInfo::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void KgpgKeyInfo::keyNeedsRefresh(KGpgKeyNode * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
