/****************************************************************************
** Meta object code from reading C++ file 'kgpgtextedit.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kgpg-17.12.3/editor/kgpgtextedit.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kgpgtextedit.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KgpgTextEdit_t {
    QByteArrayData data[21];
    char stringdata0[252];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KgpgTextEdit_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KgpgTextEdit_t qt_meta_stringdata_KgpgTextEdit = {
    {
QT_MOC_LITERAL(0, 0, 12), // "KgpgTextEdit"
QT_MOC_LITERAL(1, 13, 7), // "newText"
QT_MOC_LITERAL(2, 21, 0), // ""
QT_MOC_LITERAL(3, 22, 13), // "resetEncoding"
QT_MOC_LITERAL(4, 36, 14), // "verifyFinished"
QT_MOC_LITERAL(5, 51, 15), // "slotDroppedFile"
QT_MOC_LITERAL(6, 67, 3), // "url"
QT_MOC_LITERAL(7, 71, 10), // "slotEncode"
QT_MOC_LITERAL(8, 82, 10), // "slotDecode"
QT_MOC_LITERAL(9, 93, 8), // "slotSign"
QT_MOC_LITERAL(10, 102, 7), // "message"
QT_MOC_LITERAL(11, 110, 10), // "slotVerify"
QT_MOC_LITERAL(12, 121, 14), // "slotSignVerify"
QT_MOC_LITERAL(13, 136, 17), // "slotHighlightText"
QT_MOC_LITERAL(14, 154, 13), // "matchingindex"
QT_MOC_LITERAL(15, 168, 13), // "matchedlength"
QT_MOC_LITERAL(16, 182, 14), // "slotVerifyDone"
QT_MOC_LITERAL(17, 197, 6), // "result"
QT_MOC_LITERAL(18, 204, 16), // "slotEncodeUpdate"
QT_MOC_LITERAL(19, 221, 14), // "slotSignUpdate"
QT_MOC_LITERAL(20, 236, 15) // "slotDecryptDone"

    },
    "KgpgTextEdit\0newText\0\0resetEncoding\0"
    "verifyFinished\0slotDroppedFile\0url\0"
    "slotEncode\0slotDecode\0slotSign\0message\0"
    "slotVerify\0slotSignVerify\0slotHighlightText\0"
    "matchingindex\0matchedlength\0slotVerifyDone\0"
    "result\0slotEncodeUpdate\0slotSignUpdate\0"
    "slotDecryptDone"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KgpgTextEdit[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   84,    2, 0x06 /* Public */,
       3,    1,   85,    2, 0x06 /* Public */,
       4,    0,   88,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,   89,    2, 0x0a /* Public */,
       7,    0,   92,    2, 0x0a /* Public */,
       8,    0,   93,    2, 0x0a /* Public */,
       9,    1,   94,    2, 0x0a /* Public */,
      11,    1,   97,    2, 0x0a /* Public */,
      12,    0,  100,    2, 0x0a /* Public */,
      13,    3,  101,    2, 0x0a /* Public */,
      16,    1,  108,    2, 0x0a /* Public */,
      18,    1,  111,    2, 0x08 /* Private */,
      19,    1,  114,    2, 0x08 /* Private */,
      20,    1,  117,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QUrl,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::Int, QMetaType::Int,    2,   14,   15,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void, QMetaType::Int,   17,

       0        // eod
};

void KgpgTextEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KgpgTextEdit *_t = static_cast<KgpgTextEdit *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->newText(); break;
        case 1: _t->resetEncoding((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->verifyFinished(); break;
        case 3: _t->slotDroppedFile((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 4: _t->slotEncode(); break;
        case 5: _t->slotDecode(); break;
        case 6: _t->slotSign((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->slotVerify((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->slotSignVerify(); break;
        case 9: _t->slotHighlightText((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const int(*)>(_a[2])),(*reinterpret_cast< const int(*)>(_a[3]))); break;
        case 10: _t->slotVerifyDone((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->slotEncodeUpdate((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->slotSignUpdate((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->slotDecryptDone((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KgpgTextEdit::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KgpgTextEdit::newText)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KgpgTextEdit::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KgpgTextEdit::resetEncoding)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KgpgTextEdit::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KgpgTextEdit::verifyFinished)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject KgpgTextEdit::staticMetaObject = {
    { &KTextEdit::staticMetaObject, qt_meta_stringdata_KgpgTextEdit.data,
      qt_meta_data_KgpgTextEdit,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KgpgTextEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KgpgTextEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KgpgTextEdit.stringdata0))
        return static_cast<void*>(this);
    return KTextEdit::qt_metacast(_clname);
}

int KgpgTextEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void KgpgTextEdit::newText()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KgpgTextEdit::resetEncoding(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KgpgTextEdit::verifyFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
