/****************************************************************************
** Meta object code from reading C++ file 'keyservers.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kgpg-17.12.3/keyservers.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keyservers.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KeyServer_t {
    QByteArrayData data[31];
    char stringdata0[405];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KeyServer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KeyServer_t qt_meta_stringdata_KeyServer = {
    {
QT_MOC_LITERAL(0, 0, 9), // "KeyServer"
QT_MOC_LITERAL(1, 10, 14), // "importFinished"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 12), // "importFailed"
QT_MOC_LITERAL(4, 39, 10), // "slotImport"
QT_MOC_LITERAL(5, 50, 10), // "slotExport"
QT_MOC_LITERAL(6, 61, 6), // "keyIds"
QT_MOC_LITERAL(7, 68, 11), // "slotSetText"
QT_MOC_LITERAL(8, 80, 4), // "text"
QT_MOC_LITERAL(9, 85, 15), // "slotTextChanged"
QT_MOC_LITERAL(10, 101, 22), // "slotSetExportAttribute"
QT_MOC_LITERAL(11, 124, 4), // "attr"
QT_MOC_LITERAL(12, 129, 16), // "slotEnableProxyI"
QT_MOC_LITERAL(13, 146, 2), // "on"
QT_MOC_LITERAL(14, 149, 16), // "slotEnableProxyE"
QT_MOC_LITERAL(15, 166, 16), // "slotSetKeyserver"
QT_MOC_LITERAL(16, 183, 6), // "server"
QT_MOC_LITERAL(17, 190, 13), // "transferKeyID"
QT_MOC_LITERAL(18, 204, 13), // "slotPreImport"
QT_MOC_LITERAL(19, 218, 13), // "slotPreExport"
QT_MOC_LITERAL(20, 232, 6), // "slotOk"
QT_MOC_LITERAL(21, 239, 10), // "handleQuit"
QT_MOC_LITERAL(22, 250, 24), // "slotDownloadKeysFinished"
QT_MOC_LITERAL(23, 275, 10), // "resultcode"
QT_MOC_LITERAL(24, 286, 22), // "slotUploadKeysFinished"
QT_MOC_LITERAL(25, 309, 16), // "slotSearchResult"
QT_MOC_LITERAL(26, 326, 6), // "result"
QT_MOC_LITERAL(27, 333, 10), // "slotSearch"
QT_MOC_LITERAL(28, 344, 19), // "slotSetFilterString"
QT_MOC_LITERAL(29, 364, 10), // "expression"
QT_MOC_LITERAL(30, 375, 29) // "slotUpdateLabelOnFilterChange"

    },
    "KeyServer\0importFinished\0\0importFailed\0"
    "slotImport\0slotExport\0keyIds\0slotSetText\0"
    "text\0slotTextChanged\0slotSetExportAttribute\0"
    "attr\0slotEnableProxyI\0on\0slotEnableProxyE\0"
    "slotSetKeyserver\0server\0transferKeyID\0"
    "slotPreImport\0slotPreExport\0slotOk\0"
    "handleQuit\0slotDownloadKeysFinished\0"
    "resultcode\0slotUploadKeysFinished\0"
    "slotSearchResult\0result\0slotSearch\0"
    "slotSetFilterString\0expression\0"
    "slotUpdateLabelOnFilterChange"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KeyServer[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      21,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  119,    2, 0x06 /* Public */,
       3,    0,  122,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,  123,    2, 0x0a /* Public */,
       5,    1,  124,    2, 0x0a /* Public */,
       7,    1,  127,    2, 0x0a /* Public */,
       9,    1,  130,    2, 0x0a /* Public */,
      10,    1,  133,    2, 0x0a /* Public */,
      12,    1,  136,    2, 0x0a /* Public */,
      14,    1,  139,    2, 0x0a /* Public */,
      15,    1,  142,    2, 0x0a /* Public */,
      17,    0,  145,    2, 0x0a /* Public */,
      18,    0,  146,    2, 0x0a /* Public */,
      19,    0,  147,    2, 0x0a /* Public */,
      20,    0,  148,    2, 0x0a /* Public */,
      21,    0,  149,    2, 0x0a /* Public */,
      22,    1,  150,    2, 0x08 /* Private */,
      24,    1,  153,    2, 0x08 /* Private */,
      25,    1,  156,    2, 0x08 /* Private */,
      27,    0,  159,    2, 0x08 /* Private */,
      28,    1,  160,    2, 0x08 /* Private */,
      30,    0,  163,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QStringList,    2,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QStringList,    6,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void, QMetaType::Bool,   13,
    QMetaType::Void, QMetaType::Bool,   13,
    QMetaType::Void, QMetaType::QString,   16,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   23,
    QMetaType::Void, QMetaType::Int,   23,
    QMetaType::Void, QMetaType::Int,   26,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   29,
    QMetaType::Void,

       0        // eod
};

void KeyServer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KeyServer *_t = static_cast<KeyServer *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->importFinished((*reinterpret_cast< QStringList(*)>(_a[1]))); break;
        case 1: _t->importFailed(); break;
        case 2: _t->slotImport(); break;
        case 3: _t->slotExport((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 4: _t->slotSetText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->slotTextChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->slotSetExportAttribute((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->slotEnableProxyI((*reinterpret_cast< const bool(*)>(_a[1]))); break;
        case 8: _t->slotEnableProxyE((*reinterpret_cast< const bool(*)>(_a[1]))); break;
        case 9: _t->slotSetKeyserver((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->transferKeyID(); break;
        case 11: _t->slotPreImport(); break;
        case 12: _t->slotPreExport(); break;
        case 13: _t->slotOk(); break;
        case 14: _t->handleQuit(); break;
        case 15: _t->slotDownloadKeysFinished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->slotUploadKeysFinished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 17: _t->slotSearchResult((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->slotSearch(); break;
        case 19: _t->slotSetFilterString((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 20: _t->slotUpdateLabelOnFilterChange(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KeyServer::*_t)(QStringList );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KeyServer::importFinished)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KeyServer::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KeyServer::importFailed)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject KeyServer::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_KeyServer.data,
      qt_meta_data_KeyServer,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KeyServer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KeyServer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KeyServer.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int KeyServer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void KeyServer::importFinished(QStringList _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KeyServer::importFailed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
