/****************************************************************************
** Meta object code from reading C++ file 'kgpgeditor.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kgpg-17.12.3/editor/kgpgeditor.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kgpgeditor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KgpgEditor_t {
    QByteArrayData data[54];
    char stringdata0[671];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KgpgEditor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KgpgEditor_t qt_meta_stringdata_KgpgEditor = {
    {
QT_MOC_LITERAL(0, 0, 10), // "KgpgEditor"
QT_MOC_LITERAL(1, 11, 14), // "openChangeFont"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 16), // "openConfigDialog"
QT_MOC_LITERAL(4, 44, 16), // "openDocumentFile"
QT_MOC_LITERAL(5, 61, 3), // "url"
QT_MOC_LITERAL(6, 65, 8), // "encoding"
QT_MOC_LITERAL(7, 74, 11), // "slotSetFont"
QT_MOC_LITERAL(8, 86, 6), // "myFont"
QT_MOC_LITERAL(9, 93, 11), // "closeWindow"
QT_MOC_LITERAL(10, 105, 11), // "slotFileNew"
QT_MOC_LITERAL(11, 117, 12), // "slotFileOpen"
QT_MOC_LITERAL(12, 130, 12), // "slotFileSave"
QT_MOC_LITERAL(13, 143, 14), // "slotFileSaveAs"
QT_MOC_LITERAL(14, 158, 13), // "slotFilePrint"
QT_MOC_LITERAL(15, 172, 14), // "slotFilePreEnc"
QT_MOC_LITERAL(16, 187, 14), // "slotFilePreDec"
QT_MOC_LITERAL(17, 202, 14), // "slotKeyManager"
QT_MOC_LITERAL(18, 217, 13), // "slotFileClose"
QT_MOC_LITERAL(19, 231, 8), // "slotundo"
QT_MOC_LITERAL(20, 240, 8), // "slotredo"
QT_MOC_LITERAL(21, 249, 11), // "slotEditCut"
QT_MOC_LITERAL(22, 261, 12), // "slotEditCopy"
QT_MOC_LITERAL(23, 274, 13), // "slotEditPaste"
QT_MOC_LITERAL(24, 288, 13), // "slotSelectAll"
QT_MOC_LITERAL(25, 302, 8), // "slotFind"
QT_MOC_LITERAL(26, 311, 12), // "slotFindNext"
QT_MOC_LITERAL(27, 324, 12), // "slotFindPrev"
QT_MOC_LITERAL(28, 337, 12), // "slotFindText"
QT_MOC_LITERAL(29, 350, 14), // "slotSetCharset"
QT_MOC_LITERAL(30, 365, 17), // "slotResetEncoding"
QT_MOC_LITERAL(31, 383, 3), // "enc"
QT_MOC_LITERAL(32, 387, 13), // "checkEncoding"
QT_MOC_LITERAL(33, 401, 11), // "QTextCodec*"
QT_MOC_LITERAL(34, 413, 5), // "codec"
QT_MOC_LITERAL(35, 419, 15), // "slotPreSignFile"
QT_MOC_LITERAL(36, 435, 12), // "slotSignFile"
QT_MOC_LITERAL(37, 448, 15), // "slotSignFileFin"
QT_MOC_LITERAL(38, 464, 17), // "slotPreVerifyFile"
QT_MOC_LITERAL(39, 482, 14), // "slotVerifyFile"
QT_MOC_LITERAL(40, 497, 12), // "slotCheckMd5"
QT_MOC_LITERAL(41, 510, 18), // "importSignatureKey"
QT_MOC_LITERAL(42, 529, 2), // "id"
QT_MOC_LITERAL(43, 532, 8), // "fileName"
QT_MOC_LITERAL(44, 541, 11), // "slotOptions"
QT_MOC_LITERAL(45, 553, 17), // "slotUndoAvailable"
QT_MOC_LITERAL(46, 571, 1), // "v"
QT_MOC_LITERAL(47, 573, 17), // "slotRedoAvailable"
QT_MOC_LITERAL(48, 591, 17), // "slotCopyAvailable"
QT_MOC_LITERAL(49, 609, 8), // "modified"
QT_MOC_LITERAL(50, 618, 7), // "newText"
QT_MOC_LITERAL(51, 626, 15), // "slotLibraryDone"
QT_MOC_LITERAL(52, 642, 24), // "slotDownloadKeysFinished"
QT_MOC_LITERAL(53, 667, 3) // "ids"

    },
    "KgpgEditor\0openChangeFont\0\0openConfigDialog\0"
    "openDocumentFile\0url\0encoding\0slotSetFont\0"
    "myFont\0closeWindow\0slotFileNew\0"
    "slotFileOpen\0slotFileSave\0slotFileSaveAs\0"
    "slotFilePrint\0slotFilePreEnc\0"
    "slotFilePreDec\0slotKeyManager\0"
    "slotFileClose\0slotundo\0slotredo\0"
    "slotEditCut\0slotEditCopy\0slotEditPaste\0"
    "slotSelectAll\0slotFind\0slotFindNext\0"
    "slotFindPrev\0slotFindText\0slotSetCharset\0"
    "slotResetEncoding\0enc\0checkEncoding\0"
    "QTextCodec*\0codec\0slotPreSignFile\0"
    "slotSignFile\0slotSignFileFin\0"
    "slotPreVerifyFile\0slotVerifyFile\0"
    "slotCheckMd5\0importSignatureKey\0id\0"
    "fileName\0slotOptions\0slotUndoAvailable\0"
    "v\0slotRedoAvailable\0slotCopyAvailable\0"
    "modified\0newText\0slotLibraryDone\0"
    "slotDownloadKeysFinished\0ids"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KgpgEditor[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      43,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  229,    2, 0x06 /* Public */,
       3,    0,  230,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    2,  231,    2, 0x0a /* Public */,
       4,    1,  236,    2, 0x2a /* Public | MethodCloned */,
       7,    1,  239,    2, 0x0a /* Public */,
       9,    0,  242,    2, 0x0a /* Public */,
      10,    0,  243,    2, 0x08 /* Private */,
      11,    0,  244,    2, 0x08 /* Private */,
      12,    0,  245,    2, 0x08 /* Private */,
      13,    0,  246,    2, 0x08 /* Private */,
      14,    0,  247,    2, 0x08 /* Private */,
      15,    0,  248,    2, 0x08 /* Private */,
      16,    0,  249,    2, 0x08 /* Private */,
      17,    0,  250,    2, 0x08 /* Private */,
      18,    0,  251,    2, 0x08 /* Private */,
      19,    0,  252,    2, 0x08 /* Private */,
      20,    0,  253,    2, 0x08 /* Private */,
      21,    0,  254,    2, 0x08 /* Private */,
      22,    0,  255,    2, 0x08 /* Private */,
      23,    0,  256,    2, 0x08 /* Private */,
      24,    0,  257,    2, 0x08 /* Private */,
      25,    0,  258,    2, 0x08 /* Private */,
      26,    0,  259,    2, 0x08 /* Private */,
      27,    0,  260,    2, 0x08 /* Private */,
      28,    0,  261,    2, 0x08 /* Private */,
      29,    0,  262,    2, 0x08 /* Private */,
      30,    1,  263,    2, 0x08 /* Private */,
      32,    1,  266,    2, 0x08 /* Private */,
      35,    0,  269,    2, 0x08 /* Private */,
      36,    1,  270,    2, 0x08 /* Private */,
      37,    1,  273,    2, 0x08 /* Private */,
      38,    0,  276,    2, 0x08 /* Private */,
      39,    1,  277,    2, 0x08 /* Private */,
      40,    0,  280,    2, 0x08 /* Private */,
      41,    2,  281,    2, 0x08 /* Private */,
      44,    0,  286,    2, 0x08 /* Private */,
      45,    1,  287,    2, 0x08 /* Private */,
      47,    1,  290,    2, 0x08 /* Private */,
      48,    1,  293,    2, 0x08 /* Private */,
      49,    0,  296,    2, 0x08 /* Private */,
      50,    0,  297,    2, 0x08 /* Private */,
      51,    0,  298,    2, 0x08 /* Private */,
      52,    1,  299,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QUrl, QMetaType::QString,    5,    6,
    QMetaType::Void, QMetaType::QUrl,    5,
    QMetaType::Void, QMetaType::QFont,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   31,
    QMetaType::Bool, 0x80000000 | 33,   34,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUrl,    5,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUrl,    5,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   42,   43,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   46,
    QMetaType::Void, QMetaType::Bool,   46,
    QMetaType::Void, QMetaType::Bool,   46,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QStringList,   53,

       0        // eod
};

void KgpgEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KgpgEditor *_t = static_cast<KgpgEditor *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->openChangeFont(); break;
        case 1: _t->openConfigDialog(); break;
        case 2: _t->openDocumentFile((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 3: _t->openDocumentFile((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 4: _t->slotSetFont((*reinterpret_cast< QFont(*)>(_a[1]))); break;
        case 5: _t->closeWindow(); break;
        case 6: _t->slotFileNew(); break;
        case 7: _t->slotFileOpen(); break;
        case 8: { bool _r = _t->slotFileSave();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->slotFileSaveAs();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->slotFilePrint(); break;
        case 11: _t->slotFilePreEnc(); break;
        case 12: _t->slotFilePreDec(); break;
        case 13: _t->slotKeyManager(); break;
        case 14: _t->slotFileClose(); break;
        case 15: _t->slotundo(); break;
        case 16: _t->slotredo(); break;
        case 17: _t->slotEditCut(); break;
        case 18: _t->slotEditCopy(); break;
        case 19: _t->slotEditPaste(); break;
        case 20: _t->slotSelectAll(); break;
        case 21: _t->slotFind(); break;
        case 22: _t->slotFindNext(); break;
        case 23: _t->slotFindPrev(); break;
        case 24: _t->slotFindText(); break;
        case 25: _t->slotSetCharset(); break;
        case 26: _t->slotResetEncoding((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 27: { bool _r = _t->checkEncoding((*reinterpret_cast< QTextCodec*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 28: _t->slotPreSignFile(); break;
        case 29: _t->slotSignFile((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 30: _t->slotSignFileFin((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 31: _t->slotPreVerifyFile(); break;
        case 32: _t->slotVerifyFile((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 33: _t->slotCheckMd5(); break;
        case 34: _t->importSignatureKey((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 35: _t->slotOptions(); break;
        case 36: _t->slotUndoAvailable((*reinterpret_cast< const bool(*)>(_a[1]))); break;
        case 37: _t->slotRedoAvailable((*reinterpret_cast< const bool(*)>(_a[1]))); break;
        case 38: _t->slotCopyAvailable((*reinterpret_cast< const bool(*)>(_a[1]))); break;
        case 39: _t->modified(); break;
        case 40: _t->newText(); break;
        case 41: _t->slotLibraryDone(); break;
        case 42: _t->slotDownloadKeysFinished((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KgpgEditor::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KgpgEditor::openChangeFont)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KgpgEditor::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KgpgEditor::openConfigDialog)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject KgpgEditor::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_KgpgEditor.data,
      qt_meta_data_KgpgEditor,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KgpgEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KgpgEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KgpgEditor.stringdata0))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KgpgEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 43)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 43)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 43;
    }
    return _id;
}

// SIGNAL 0
void KgpgEditor::openChangeFont()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KgpgEditor::openConfigDialog()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
