#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'kgpgkeygenerate.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KGPGKEYGENERATE_H
#define UI_KGPGKEYGENERATE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_kgpgKeyGenerate
{
public:
    QGroupBox *vgroup;
    QVBoxLayout *verticalLayout;
    QLabel *nameLabel;
    QLineEdit *m_kname;
    QLabel *emailLabel;
    QLineEdit *m_mail;
    QLabel *label_2;
    QLineEdit *m_comment;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout;
    QSpinBox *m_days;
    QComboBox *m_keyexp;
    QLabel *label_4;
    QComboBox *m_keysize;
    QLabel *label_5;
    QComboBox *m_keykind;
    QGroupBox *capabilities;
    QFormLayout *formLayout;
    QCheckBox *capCert;
    QCheckBox *capSign;
    QCheckBox *capAuth;
    QCheckBox *capEncrypt;

    void setupUi(QDialog *kgpgKeyGenerate)
    {
        if (kgpgKeyGenerate->objectName().isEmpty())
            kgpgKeyGenerate->setObjectName(QStringLiteral("kgpgKeyGenerate"));
        kgpgKeyGenerate->resize(367, 464);
        vgroup = new QGroupBox(kgpgKeyGenerate);
        vgroup->setObjectName(QStringLiteral("vgroup"));
        vgroup->setGeometry(QRect(0, 10, 361, 434));
        verticalLayout = new QVBoxLayout(vgroup);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        nameLabel = new QLabel(vgroup);
        nameLabel->setObjectName(QStringLiteral("nameLabel"));

        verticalLayout->addWidget(nameLabel);

        m_kname = new QLineEdit(vgroup);
        m_kname->setObjectName(QStringLiteral("m_kname"));

        verticalLayout->addWidget(m_kname);

        emailLabel = new QLabel(vgroup);
        emailLabel->setObjectName(QStringLiteral("emailLabel"));

        verticalLayout->addWidget(emailLabel);

        m_mail = new QLineEdit(vgroup);
        m_mail->setObjectName(QStringLiteral("m_mail"));

        verticalLayout->addWidget(m_mail);

        label_2 = new QLabel(vgroup);
        label_2->setObjectName(QStringLiteral("label_2"));

        verticalLayout->addWidget(label_2);

        m_comment = new QLineEdit(vgroup);
        m_comment->setObjectName(QStringLiteral("m_comment"));

        verticalLayout->addWidget(m_comment);

        label_3 = new QLabel(vgroup);
        label_3->setObjectName(QStringLiteral("label_3"));

        verticalLayout->addWidget(label_3);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        m_days = new QSpinBox(vgroup);
        m_days->setObjectName(QStringLiteral("m_days"));
        m_days->setEnabled(false);
        m_days->setMaximum(9999);

        horizontalLayout->addWidget(m_days);

        m_keyexp = new QComboBox(vgroup);
        m_keyexp->setObjectName(QStringLiteral("m_keyexp"));

        horizontalLayout->addWidget(m_keyexp);


        verticalLayout->addLayout(horizontalLayout);

        label_4 = new QLabel(vgroup);
        label_4->setObjectName(QStringLiteral("label_4"));

        verticalLayout->addWidget(label_4);

        m_keysize = new QComboBox(vgroup);
        m_keysize->setObjectName(QStringLiteral("m_keysize"));

        verticalLayout->addWidget(m_keysize);

        label_5 = new QLabel(vgroup);
        label_5->setObjectName(QStringLiteral("label_5"));

        verticalLayout->addWidget(label_5);

        m_keykind = new QComboBox(vgroup);
        m_keykind->setObjectName(QStringLiteral("m_keykind"));

        verticalLayout->addWidget(m_keykind);

        capabilities = new QGroupBox(vgroup);
        capabilities->setObjectName(QStringLiteral("capabilities"));
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(capabilities->sizePolicy().hasHeightForWidth());
        capabilities->setSizePolicy(sizePolicy);
        formLayout = new QFormLayout(capabilities);
        formLayout->setObjectName(QStringLiteral("formLayout"));
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        capCert = new QCheckBox(capabilities);
        capCert->setObjectName(QStringLiteral("capCert"));
        capCert->setEnabled(false);
        capCert->setChecked(true);

        formLayout->setWidget(0, QFormLayout::FieldRole, capCert);

        capSign = new QCheckBox(capabilities);
        capSign->setObjectName(QStringLiteral("capSign"));
        capSign->setChecked(true);

        formLayout->setWidget(3, QFormLayout::FieldRole, capSign);

        capAuth = new QCheckBox(capabilities);
        capAuth->setObjectName(QStringLiteral("capAuth"));
        capAuth->setChecked(true);

        formLayout->setWidget(1, QFormLayout::FieldRole, capAuth);

        capEncrypt = new QCheckBox(capabilities);
        capEncrypt->setObjectName(QStringLiteral("capEncrypt"));
        capEncrypt->setChecked(true);

        formLayout->setWidget(2, QFormLayout::FieldRole, capEncrypt);


        verticalLayout->addWidget(capabilities);

#ifndef UI_QT_NO_SHORTCUT
        nameLabel->setBuddy(m_kname);
        emailLabel->setBuddy(m_mail);
        label_2->setBuddy(m_comment);
        label_4->setBuddy(m_keysize);
        label_5->setBuddy(m_keykind);
#endif // QT_NO_SHORTCUT

        retranslateUi(kgpgKeyGenerate);

        QMetaObject::connectSlotsByName(kgpgKeyGenerate);
    } // setupUi

    void retranslateUi(QDialog *kgpgKeyGenerate)
    {
        kgpgKeyGenerate->setWindowTitle(tr2i18n("Key Generation", Q_NULLPTR));
        vgroup->setTitle(tr2i18n("Generate Key Pair", Q_NULLPTR));
        nameLabel->setText(tr2i18n("&Name:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        m_kname->setToolTip(tr2i18n("The name must have a length of at least 5 characters and must not begin with a digit.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        m_kname->setPlaceholderText(tr2i18n("Real name, at least 5 characters, no leading digits", Q_NULLPTR));
        emailLabel->setText(tr2i18n("E&mail (optional):", Q_NULLPTR));
        label_2->setText(tr2i18n("Commen&t (optional):", Q_NULLPTR));
        label_3->setText(tr2i18n("Expiration:", Q_NULLPTR));
        m_keyexp->clear();
        m_keyexp->insertItems(0, QStringList()
         << tr2i18n("Never", "Key will not expire")
         << tr2i18n("Days", Q_NULLPTR)
         << tr2i18n("Weeks", Q_NULLPTR)
         << tr2i18n("Months", Q_NULLPTR)
         << tr2i18n("Years", Q_NULLPTR)
        );
        label_4->setText(tr2i18n("&Key size:", Q_NULLPTR));
        label_5->setText(tr2i18n("&Algorithm:", Q_NULLPTR));
        capabilities->setTitle(tr2i18n("Capabilities", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        capCert->setToolTip(tr2i18n("Certification is automatically enabled for all keys", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        capCert->setText(tr2i18n("Certification", Q_NULLPTR));
        capSign->setText(tr2i18n("Signature", Q_NULLPTR));
        capAuth->setText(tr2i18n("Authentication", Q_NULLPTR));
        capEncrypt->setText(tr2i18n("Encryption", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class kgpgKeyGenerate: public Ui_kgpgKeyGenerate {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KGPGKEYGENERATE_H

