/****************************************************************************
** Meta object code from reading C++ file 'kgpgexternalactions.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kgpg-17.12.3/kgpgexternalactions.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kgpgexternalactions.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KGpgExternalActions_t {
    QByteArrayData data[18];
    char stringdata0[236];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KGpgExternalActions_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KGpgExternalActions_t qt_meta_stringdata_KGpgExternalActions = {
    {
QT_MOC_LITERAL(0, 0, 19), // "KGpgExternalActions"
QT_MOC_LITERAL(1, 20, 12), // "createNewKey"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 13), // "updateDefault"
QT_MOC_LITERAL(4, 48, 17), // "startFolderEncode"
QT_MOC_LITERAL(5, 66, 19), // "slotSaveOptionsPath"
QT_MOC_LITERAL(6, 86, 20), // "slotVerificationDone"
QT_MOC_LITERAL(7, 107, 6), // "result"
QT_MOC_LITERAL(8, 114, 4), // "help"
QT_MOC_LITERAL(9, 119, 18), // "slotSetCompression"
QT_MOC_LITERAL(10, 138, 2), // "cp"
QT_MOC_LITERAL(11, 141, 18), // "slotDecryptionDone"
QT_MOC_LITERAL(12, 160, 6), // "status"
QT_MOC_LITERAL(13, 167, 18), // "slotFolderFinished"
QT_MOC_LITERAL(14, 186, 5), // "KJob*"
QT_MOC_LITERAL(15, 192, 3), // "job"
QT_MOC_LITERAL(16, 196, 13), // "slotSignFiles"
QT_MOC_LITERAL(17, 210, 25) // "slotEncryptionKeySelected"

    },
    "KGpgExternalActions\0createNewKey\0\0"
    "updateDefault\0startFolderEncode\0"
    "slotSaveOptionsPath\0slotVerificationDone\0"
    "result\0help\0slotSetCompression\0cp\0"
    "slotDecryptionDone\0status\0slotFolderFinished\0"
    "KJob*\0job\0slotSignFiles\0"
    "slotEncryptionKeySelected"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KGpgExternalActions[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   69,    2, 0x06 /* Public */,
       3,    1,   70,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,   73,    2, 0x08 /* Private */,
       5,    0,   74,    2, 0x08 /* Private */,
       6,    1,   75,    2, 0x08 /* Private */,
       8,    0,   78,    2, 0x08 /* Private */,
       9,    1,   79,    2, 0x08 /* Private */,
      11,    1,   82,    2, 0x08 /* Private */,
      13,    1,   85,    2, 0x08 /* Private */,
      16,    0,   88,    2, 0x08 /* Private */,
      17,    0,   89,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KGpgExternalActions::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KGpgExternalActions *_t = static_cast<KGpgExternalActions *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->createNewKey(); break;
        case 1: _t->updateDefault((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 2: _t->startFolderEncode(); break;
        case 3: _t->slotSaveOptionsPath(); break;
        case 4: _t->slotVerificationDone((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->help(); break;
        case 6: _t->slotSetCompression((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->slotDecryptionDone((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->slotFolderFinished((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 9: _t->slotSignFiles(); break;
        case 10: _t->slotEncryptionKeySelected(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KGpgExternalActions::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KGpgExternalActions::createNewKey)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KGpgExternalActions::*_t)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KGpgExternalActions::updateDefault)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject KGpgExternalActions::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KGpgExternalActions.data,
      qt_meta_data_KGpgExternalActions,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KGpgExternalActions::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KGpgExternalActions::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KGpgExternalActions.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KGpgExternalActions::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void KGpgExternalActions::createNewKey()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KGpgExternalActions::updateDefault(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
