/****************************************************************************
** Meta object code from reading C++ file 'keysmanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kgpg-17.12.3/keysmanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#include <QtCore/QSet>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keysmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KeysManager_t {
    QByteArrayData data[119];
    char stringdata0[1580];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KeysManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KeysManager_t qt_meta_stringdata_KeysManager = {
    {
QT_MOC_LITERAL(0, 0, 11), // "KeysManager"
QT_MOC_LITERAL(1, 12, 16), // "readAgainOptions"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 11), // "certificate"
QT_MOC_LITERAL(4, 42, 10), // "closeAsked"
QT_MOC_LITERAL(5, 53, 11), // "fontChanged"
QT_MOC_LITERAL(6, 65, 15), // "slotGenerateKey"
QT_MOC_LITERAL(7, 81, 10), // "refreshkey"
QT_MOC_LITERAL(8, 92, 14), // "readAllOptions"
QT_MOC_LITERAL(9, 107, 11), // "showKeyInfo"
QT_MOC_LITERAL(10, 119, 5), // "keyID"
QT_MOC_LITERAL(11, 125, 17), // "slotSetDefaultKey"
QT_MOC_LITERAL(12, 143, 5), // "newID"
QT_MOC_LITERAL(13, 149, 14), // "showKeyManager"
QT_MOC_LITERAL(14, 164, 15), // "importRemoteKey"
QT_MOC_LITERAL(15, 180, 6), // "keyIDs"
QT_MOC_LITERAL(16, 187, 16), // "importRemoteKeys"
QT_MOC_LITERAL(17, 204, 6), // "dialog"
QT_MOC_LITERAL(18, 211, 13), // "showKeyServer"
QT_MOC_LITERAL(19, 225, 11), // "showOptions"
QT_MOC_LITERAL(20, 237, 14), // "slotOpenEditor"
QT_MOC_LITERAL(21, 252, 10), // "slotImport"
QT_MOC_LITERAL(22, 263, 4), // "text"
QT_MOC_LITERAL(23, 268, 11), // "QList<QUrl>"
QT_MOC_LITERAL(24, 280, 5), // "files"
QT_MOC_LITERAL(25, 286, 11), // "clipEncrypt"
QT_MOC_LITERAL(26, 298, 11), // "clipDecrypt"
QT_MOC_LITERAL(27, 310, 8), // "clipSign"
QT_MOC_LITERAL(28, 319, 14), // "slotImportDone"
QT_MOC_LITERAL(29, 334, 3), // "ret"
QT_MOC_LITERAL(30, 338, 19), // "slotGenerateKeyDone"
QT_MOC_LITERAL(31, 358, 5), // "KJob*"
QT_MOC_LITERAL(32, 364, 3), // "job"
QT_MOC_LITERAL(33, 368, 13), // "slotShowTrust"
QT_MOC_LITERAL(34, 382, 12), // "slotShowSize"
QT_MOC_LITERAL(35, 395, 16), // "slotShowCreation"
QT_MOC_LITERAL(36, 412, 18), // "slotShowExpiration"
QT_MOC_LITERAL(37, 431, 13), // "slotAddUidFin"
QT_MOC_LITERAL(38, 445, 3), // "res"
QT_MOC_LITERAL(39, 449, 20), // "slotDelPhotoFinished"
QT_MOC_LITERAL(40, 470, 7), // "quitApp"
QT_MOC_LITERAL(41, 478, 14), // "slotShowLongId"
QT_MOC_LITERAL(42, 493, 18), // "slotSetTrustFilter"
QT_MOC_LITERAL(43, 512, 18), // "slotGotoDefaultKey"
QT_MOC_LITERAL(44, 531, 10), // "slotDelUid"
QT_MOC_LITERAL(45, 542, 14), // "slotDelUidDone"
QT_MOC_LITERAL(46, 557, 11), // "slotPrimUid"
QT_MOC_LITERAL(47, 569, 15), // "slotPrimUidDone"
QT_MOC_LITERAL(48, 585, 6), // "result"
QT_MOC_LITERAL(49, 592, 10), // "slotAddUid"
QT_MOC_LITERAL(50, 603, 16), // "slotAddUidEnable"
QT_MOC_LITERAL(51, 620, 4), // "name"
QT_MOC_LITERAL(52, 625, 15), // "slotUpdatePhoto"
QT_MOC_LITERAL(53, 641, 15), // "slotDeletePhoto"
QT_MOC_LITERAL(54, 657, 12), // "slotAddPhoto"
QT_MOC_LITERAL(55, 670, 20), // "slotAddPhotoFinished"
QT_MOC_LITERAL(56, 691, 16), // "slotSetPhotoSize"
QT_MOC_LITERAL(57, 708, 4), // "size"
QT_MOC_LITERAL(58, 713, 13), // "slotShowPhoto"
QT_MOC_LITERAL(59, 727, 12), // "revokeWidget"
QT_MOC_LITERAL(60, 740, 24), // "slotRevokeDialogFinished"
QT_MOC_LITERAL(61, 765, 19), // "slotRevokeGenerated"
QT_MOC_LITERAL(62, 785, 7), // "doPrint"
QT_MOC_LITERAL(63, 793, 3), // "txt"
QT_MOC_LITERAL(64, 797, 9), // "checkList"
QT_MOC_LITERAL(65, 807, 11), // "slotManpage"
QT_MOC_LITERAL(66, 819, 7), // "slotTip"
QT_MOC_LITERAL(67, 827, 18), // "slotExportFinished"
QT_MOC_LITERAL(68, 846, 21), // "slotProcessExportMail"
QT_MOC_LITERAL(69, 868, 21), // "slotProcessExportClip"
QT_MOC_LITERAL(70, 890, 11), // "readOptions"
QT_MOC_LITERAL(71, 902, 13), // "slotSetDefKey"
QT_MOC_LITERAL(72, 916, 16), // "confirmdeletekey"
QT_MOC_LITERAL(73, 933, 12), // "deleteseckey"
QT_MOC_LITERAL(74, 946, 7), // "signkey"
QT_MOC_LITERAL(75, 954, 7), // "signuid"
QT_MOC_LITERAL(76, 962, 4), // "caff"
QT_MOC_LITERAL(77, 967, 12), // "slotCaffDone"
QT_MOC_LITERAL(78, 980, 10), // "delsignkey"
QT_MOC_LITERAL(79, 991, 16), // "preimportsignkey"
QT_MOC_LITERAL(80, 1008, 16), // "importallsignkey"
QT_MOC_LITERAL(81, 1025, 15), // "signatureResult"
QT_MOC_LITERAL(82, 1041, 7), // "success"
QT_MOC_LITERAL(83, 1049, 18), // "delsignatureResult"
QT_MOC_LITERAL(84, 1068, 13), // "defaultAction"
QT_MOC_LITERAL(85, 1082, 9), // "KGpgNode*"
QT_MOC_LITERAL(86, 1092, 17), // "slotDefaultAction"
QT_MOC_LITERAL(87, 1110, 14), // "showProperties"
QT_MOC_LITERAL(88, 1125, 13), // "keyproperties"
QT_MOC_LITERAL(89, 1139, 10), // "slotexport"
QT_MOC_LITERAL(90, 1150, 13), // "slotexportsec"
QT_MOC_LITERAL(91, 1164, 21), // "slotExportSecFinished"
QT_MOC_LITERAL(92, 1186, 8), // "slotMenu"
QT_MOC_LITERAL(93, 1195, 16), // "slotPreImportKey"
QT_MOC_LITERAL(94, 1212, 13), // "slotSendEmail"
QT_MOC_LITERAL(95, 1226, 8), // "slotedit"
QT_MOC_LITERAL(96, 1235, 8), // "addToKAB"
QT_MOC_LITERAL(97, 1244, 27), // "slotAddressbookSearchResult"
QT_MOC_LITERAL(98, 1272, 9), // "editGroup"
QT_MOC_LITERAL(99, 1282, 14), // "createNewGroup"
QT_MOC_LITERAL(100, 1297, 11), // "deleteGroup"
QT_MOC_LITERAL(101, 1309, 11), // "renameGroup"
QT_MOC_LITERAL(102, 1321, 19), // "slotImportRevokeTxt"
QT_MOC_LITERAL(103, 1341, 10), // "revokeText"
QT_MOC_LITERAL(104, 1352, 20), // "refreshKeyFromServer"
QT_MOC_LITERAL(105, 1373, 18), // "slotKeyRefreshDone"
QT_MOC_LITERAL(106, 1392, 14), // "slotregenerate"
QT_MOC_LITERAL(107, 1407, 16), // "secretKeyDeleted"
QT_MOC_LITERAL(108, 1424, 14), // "getMissingSigs"
QT_MOC_LITERAL(109, 1439, 14), // "QSet<QString>&"
QT_MOC_LITERAL(110, 1454, 11), // "missingKeys"
QT_MOC_LITERAL(111, 1466, 25), // "const KGpgExpandableNode*"
QT_MOC_LITERAL(112, 1492, 2), // "nd"
QT_MOC_LITERAL(113, 1495, 12), // "slotEditDone"
QT_MOC_LITERAL(114, 1508, 8), // "exitcode"
QT_MOC_LITERAL(115, 1517, 20), // "importRemoteFinished"
QT_MOC_LITERAL(116, 1538, 14), // "slotDelKeyDone"
QT_MOC_LITERAL(117, 1553, 11), // "slotSetClip"
QT_MOC_LITERAL(118, 1565, 14) // "slotOpenKeyUrl"

    },
    "KeysManager\0readAgainOptions\0\0certificate\0"
    "closeAsked\0fontChanged\0slotGenerateKey\0"
    "refreshkey\0readAllOptions\0showKeyInfo\0"
    "keyID\0slotSetDefaultKey\0newID\0"
    "showKeyManager\0importRemoteKey\0keyIDs\0"
    "importRemoteKeys\0dialog\0showKeyServer\0"
    "showOptions\0slotOpenEditor\0slotImport\0"
    "text\0QList<QUrl>\0files\0clipEncrypt\0"
    "clipDecrypt\0clipSign\0slotImportDone\0"
    "ret\0slotGenerateKeyDone\0KJob*\0job\0"
    "slotShowTrust\0slotShowSize\0slotShowCreation\0"
    "slotShowExpiration\0slotAddUidFin\0res\0"
    "slotDelPhotoFinished\0quitApp\0"
    "slotShowLongId\0slotSetTrustFilter\0"
    "slotGotoDefaultKey\0slotDelUid\0"
    "slotDelUidDone\0slotPrimUid\0slotPrimUidDone\0"
    "result\0slotAddUid\0slotAddUidEnable\0"
    "name\0slotUpdatePhoto\0slotDeletePhoto\0"
    "slotAddPhoto\0slotAddPhotoFinished\0"
    "slotSetPhotoSize\0size\0slotShowPhoto\0"
    "revokeWidget\0slotRevokeDialogFinished\0"
    "slotRevokeGenerated\0doPrint\0txt\0"
    "checkList\0slotManpage\0slotTip\0"
    "slotExportFinished\0slotProcessExportMail\0"
    "slotProcessExportClip\0readOptions\0"
    "slotSetDefKey\0confirmdeletekey\0"
    "deleteseckey\0signkey\0signuid\0caff\0"
    "slotCaffDone\0delsignkey\0preimportsignkey\0"
    "importallsignkey\0signatureResult\0"
    "success\0delsignatureResult\0defaultAction\0"
    "KGpgNode*\0slotDefaultAction\0showProperties\0"
    "keyproperties\0slotexport\0slotexportsec\0"
    "slotExportSecFinished\0slotMenu\0"
    "slotPreImportKey\0slotSendEmail\0slotedit\0"
    "addToKAB\0slotAddressbookSearchResult\0"
    "editGroup\0createNewGroup\0deleteGroup\0"
    "renameGroup\0slotImportRevokeTxt\0"
    "revokeText\0refreshKeyFromServer\0"
    "slotKeyRefreshDone\0slotregenerate\0"
    "secretKeyDeleted\0getMissingSigs\0"
    "QSet<QString>&\0missingKeys\0"
    "const KGpgExpandableNode*\0nd\0slotEditDone\0"
    "exitcode\0importRemoteFinished\0"
    "slotDelKeyDone\0slotSetClip\0slotOpenKeyUrl"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KeysManager[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      97,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  499,    2, 0x06 /* Public */,
       3,    1,  500,    2, 0x06 /* Public */,
       4,    0,  503,    2, 0x06 /* Public */,
       5,    1,  504,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    0,  507,    2, 0x0a /* Public */,
       7,    0,  508,    2, 0x0a /* Public */,
       8,    0,  509,    2, 0x0a /* Public */,
       9,    1,  510,    2, 0x0a /* Public */,
      11,    1,  513,    2, 0x0a /* Public */,
      13,    0,  516,    2, 0x0a /* Public */,
      14,    1,  517,    2, 0x0a /* Public */,
      16,    2,  520,    2, 0x0a /* Public */,
      16,    1,  525,    2, 0x2a /* Public | MethodCloned */,
      18,    0,  528,    2, 0x0a /* Public */,
      19,    0,  529,    2, 0x0a /* Public */,
      20,    0,  530,    2, 0x0a /* Public */,
      21,    1,  531,    2, 0x0a /* Public */,
      21,    1,  534,    2, 0x0a /* Public */,
      25,    0,  537,    2, 0x0a /* Public */,
      26,    0,  538,    2, 0x0a /* Public */,
      27,    0,  539,    2, 0x0a /* Public */,
      28,    1,  540,    2, 0x0a /* Public */,
      30,    1,  543,    2, 0x08 /* Private */,
      33,    0,  546,    2, 0x08 /* Private */,
      34,    0,  547,    2, 0x08 /* Private */,
      35,    0,  548,    2, 0x08 /* Private */,
      36,    0,  549,    2, 0x08 /* Private */,
      37,    1,  550,    2, 0x08 /* Private */,
      39,    1,  553,    2, 0x08 /* Private */,
      40,    0,  556,    2, 0x08 /* Private */,
      41,    1,  557,    2, 0x08 /* Private */,
      42,    1,  560,    2, 0x08 /* Private */,
      43,    0,  563,    2, 0x08 /* Private */,
      44,    0,  564,    2, 0x08 /* Private */,
      45,    1,  565,    2, 0x08 /* Private */,
      46,    0,  568,    2, 0x08 /* Private */,
      47,    1,  569,    2, 0x08 /* Private */,
      49,    0,  572,    2, 0x08 /* Private */,
      50,    1,  573,    2, 0x08 /* Private */,
      52,    0,  576,    2, 0x08 /* Private */,
      53,    0,  577,    2, 0x08 /* Private */,
      54,    0,  578,    2, 0x08 /* Private */,
      55,    1,  579,    2, 0x08 /* Private */,
      56,    1,  582,    2, 0x08 /* Private */,
      58,    0,  585,    2, 0x08 /* Private */,
      59,    0,  586,    2, 0x08 /* Private */,
      60,    1,  587,    2, 0x08 /* Private */,
      61,    1,  590,    2, 0x08 /* Private */,
      62,    1,  593,    2, 0x08 /* Private */,
      64,    0,  596,    2, 0x08 /* Private */,
      65,    0,  597,    2, 0x08 /* Private */,
      66,    0,  598,    2, 0x08 /* Private */,
      67,    1,  599,    2, 0x08 /* Private */,
      68,    1,  602,    2, 0x08 /* Private */,
      69,    1,  605,    2, 0x08 /* Private */,
      70,    0,  608,    2, 0x08 /* Private */,
      71,    0,  609,    2, 0x08 /* Private */,
      72,    0,  610,    2, 0x08 /* Private */,
      73,    0,  611,    2, 0x08 /* Private */,
      74,    0,  612,    2, 0x08 /* Private */,
      75,    0,  613,    2, 0x08 /* Private */,
      76,    0,  614,    2, 0x08 /* Private */,
      77,    0,  615,    2, 0x08 /* Private */,
      78,    0,  616,    2, 0x08 /* Private */,
      79,    0,  617,    2, 0x08 /* Private */,
      80,    0,  618,    2, 0x08 /* Private */,
      81,    1,  619,    2, 0x08 /* Private */,
      83,    1,  622,    2, 0x08 /* Private */,
      84,    1,  625,    2, 0x08 /* Private */,
      84,    1,  628,    2, 0x08 /* Private */,
      86,    0,  631,    2, 0x08 /* Private */,
      87,    1,  632,    2, 0x08 /* Private */,
      88,    0,  635,    2, 0x08 /* Private */,
      89,    0,  636,    2, 0x08 /* Private */,
      90,    0,  637,    2, 0x08 /* Private */,
      91,    1,  638,    2, 0x08 /* Private */,
      92,    1,  641,    2, 0x08 /* Private */,
      93,    0,  644,    2, 0x08 /* Private */,
      94,    0,  645,    2, 0x08 /* Private */,
      95,    0,  646,    2, 0x08 /* Private */,
      96,    0,  647,    2, 0x08 /* Private */,
      97,    1,  648,    2, 0x08 /* Private */,
      98,    0,  651,    2, 0x08 /* Private */,
      99,    0,  652,    2, 0x08 /* Private */,
     100,    0,  653,    2, 0x08 /* Private */,
     101,    0,  654,    2, 0x08 /* Private */,
     102,    1,  655,    2, 0x08 /* Private */,
     104,    0,  658,    2, 0x08 /* Private */,
     105,    1,  659,    2, 0x08 /* Private */,
     106,    0,  662,    2, 0x08 /* Private */,
     107,    1,  663,    2, 0x08 /* Private */,
     108,    2,  666,    2, 0x08 /* Private */,
     113,    1,  671,    2, 0x08 /* Private */,
     115,    1,  674,    2, 0x08 /* Private */,
     116,    1,  677,    2, 0x08 /* Private */,
     117,    1,  680,    2, 0x08 /* Private */,
     118,    0,  683,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QFont,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void, QMetaType::QString,   12,
    QMetaType::Void,
    QMetaType::Bool, QMetaType::QString,   15,
    QMetaType::Bool, QMetaType::QStringList, QMetaType::Bool,   15,   17,
    QMetaType::Bool, QMetaType::QStringList,   15,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   22,
    QMetaType::Void, 0x80000000 | 23,   24,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   29,
    QMetaType::Void, 0x80000000 | 31,   32,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   38,
    QMetaType::Void, QMetaType::Int,   38,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   48,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   51,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   38,
    QMetaType::Void, QMetaType::Int,   57,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   48,
    QMetaType::Void, QMetaType::Int,   48,
    QMetaType::Void, QMetaType::QString,   63,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   48,
    QMetaType::Void, QMetaType::Int,   48,
    QMetaType::Void, QMetaType::Int,   48,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   82,
    QMetaType::Void, QMetaType::Int,   82,
    QMetaType::Void, QMetaType::QModelIndex,    2,
    QMetaType::Void, 0x80000000 | 85,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 85,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   48,
    QMetaType::Void, QMetaType::QPoint,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 31,   32,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,  103,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   48,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, 0x80000000 | 109, 0x80000000 | 111,  110,  112,
    QMetaType::Void, QMetaType::Int,  114,
    QMetaType::Void, QMetaType::Int,   48,
    QMetaType::Void, QMetaType::Int,   29,
    QMetaType::Void, QMetaType::Int,   48,
    QMetaType::Void,

       0        // eod
};

void KeysManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KeysManager *_t = static_cast<KeysManager *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->readAgainOptions(); break;
        case 1: _t->certificate((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 2: _t->closeAsked(); break;
        case 3: _t->fontChanged((*reinterpret_cast< QFont(*)>(_a[1]))); break;
        case 4: _t->slotGenerateKey(); break;
        case 5: _t->refreshkey(); break;
        case 6: _t->readAllOptions(); break;
        case 7: _t->showKeyInfo((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->slotSetDefaultKey((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->showKeyManager(); break;
        case 10: { bool _r = _t->importRemoteKey((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->importRemoteKeys((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const bool(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->importRemoteKeys((*reinterpret_cast< const QStringList(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->showKeyServer(); break;
        case 14: _t->showOptions(); break;
        case 15: _t->slotOpenEditor(); break;
        case 16: _t->slotImport((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 17: _t->slotImport((*reinterpret_cast< const QList<QUrl>(*)>(_a[1]))); break;
        case 18: _t->clipEncrypt(); break;
        case 19: _t->clipDecrypt(); break;
        case 20: _t->clipSign(); break;
        case 21: _t->slotImportDone((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 22: _t->slotGenerateKeyDone((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 23: _t->slotShowTrust(); break;
        case 24: _t->slotShowSize(); break;
        case 25: _t->slotShowCreation(); break;
        case 26: _t->slotShowExpiration(); break;
        case 27: _t->slotAddUidFin((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 28: _t->slotDelPhotoFinished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 29: _t->quitApp(); break;
        case 30: _t->slotShowLongId((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 31: _t->slotSetTrustFilter((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 32: _t->slotGotoDefaultKey(); break;
        case 33: _t->slotDelUid(); break;
        case 34: _t->slotDelUidDone((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 35: _t->slotPrimUid(); break;
        case 36: _t->slotPrimUidDone((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 37: _t->slotAddUid(); break;
        case 38: _t->slotAddUidEnable((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 39: _t->slotUpdatePhoto(); break;
        case 40: _t->slotDeletePhoto(); break;
        case 41: _t->slotAddPhoto(); break;
        case 42: _t->slotAddPhotoFinished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 43: _t->slotSetPhotoSize((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 44: _t->slotShowPhoto(); break;
        case 45: _t->revokeWidget(); break;
        case 46: _t->slotRevokeDialogFinished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 47: _t->slotRevokeGenerated((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 48: _t->doPrint((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 49: _t->checkList(); break;
        case 50: _t->slotManpage(); break;
        case 51: _t->slotTip(); break;
        case 52: _t->slotExportFinished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 53: _t->slotProcessExportMail((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 54: _t->slotProcessExportClip((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 55: _t->readOptions(); break;
        case 56: _t->slotSetDefKey(); break;
        case 57: _t->confirmdeletekey(); break;
        case 58: _t->deleteseckey(); break;
        case 59: _t->signkey(); break;
        case 60: _t->signuid(); break;
        case 61: _t->caff(); break;
        case 62: _t->slotCaffDone(); break;
        case 63: _t->delsignkey(); break;
        case 64: _t->preimportsignkey(); break;
        case 65: _t->importallsignkey(); break;
        case 66: _t->signatureResult((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 67: _t->delsignatureResult((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 68: _t->defaultAction((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 69: _t->defaultAction((*reinterpret_cast< KGpgNode*(*)>(_a[1]))); break;
        case 70: _t->slotDefaultAction(); break;
        case 71: _t->showProperties((*reinterpret_cast< KGpgNode*(*)>(_a[1]))); break;
        case 72: _t->keyproperties(); break;
        case 73: _t->slotexport(); break;
        case 74: _t->slotexportsec(); break;
        case 75: _t->slotExportSecFinished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 76: _t->slotMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 77: _t->slotPreImportKey(); break;
        case 78: _t->slotSendEmail(); break;
        case 79: _t->slotedit(); break;
        case 80: _t->addToKAB(); break;
        case 81: _t->slotAddressbookSearchResult((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 82: _t->editGroup(); break;
        case 83: _t->createNewGroup(); break;
        case 84: _t->deleteGroup(); break;
        case 85: _t->renameGroup(); break;
        case 86: _t->slotImportRevokeTxt((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 87: _t->refreshKeyFromServer(); break;
        case 88: _t->slotKeyRefreshDone((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 89: _t->slotregenerate(); break;
        case 90: _t->secretKeyDeleted((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 91: _t->getMissingSigs((*reinterpret_cast< QSet<QString>(*)>(_a[1])),(*reinterpret_cast< const KGpgExpandableNode*(*)>(_a[2]))); break;
        case 92: _t->slotEditDone((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 93: _t->importRemoteFinished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 94: _t->slotDelKeyDone((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 95: _t->slotSetClip((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 96: _t->slotOpenKeyUrl(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            }
            break;
        case 69:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KGpgNode* >(); break;
            }
            break;
        case 71:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KGpgNode* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KeysManager::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KeysManager::readAgainOptions)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KeysManager::*_t)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KeysManager::certificate)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KeysManager::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KeysManager::closeAsked)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KeysManager::*_t)(QFont );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KeysManager::fontChanged)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject KeysManager::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_KeysManager.data,
      qt_meta_data_KeysManager,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KeysManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KeysManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KeysManager.stringdata0))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KeysManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 97)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 97;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 97)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 97;
    }
    return _id;
}

// SIGNAL 0
void KeysManager::readAgainOptions()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KeysManager::certificate(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KeysManager::closeAsked()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KeysManager::fontChanged(QFont _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
