/****************************************************************************
** Meta object code from reading C++ file 'kgpgitemmodel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kgpg-17.12.3/model/kgpgitemmodel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kgpgitemmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KGpgItemModel_t {
    QByteArrayData data[33];
    char stringdata0[343];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KGpgItemModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KGpgItemModel_t qt_meta_stringdata_KGpgItemModel = {
    {
QT_MOC_LITERAL(0, 0, 13), // "KGpgItemModel"
QT_MOC_LITERAL(1, 14, 8), // "addGroup"
QT_MOC_LITERAL(2, 23, 14), // "KGpgGroupNode*"
QT_MOC_LITERAL(3, 38, 0), // ""
QT_MOC_LITERAL(4, 39, 4), // "name"
QT_MOC_LITERAL(5, 44, 17), // "KGpgKeyNode::List"
QT_MOC_LITERAL(6, 62, 4), // "keys"
QT_MOC_LITERAL(7, 67, 7), // "delNode"
QT_MOC_LITERAL(8, 75, 9), // "KGpgNode*"
QT_MOC_LITERAL(9, 85, 4), // "node"
QT_MOC_LITERAL(10, 90, 11), // "changeGroup"
QT_MOC_LITERAL(11, 102, 14), // "KGpgNode::List"
QT_MOC_LITERAL(12, 117, 15), // "deleteFromGroup"
QT_MOC_LITERAL(13, 133, 5), // "group"
QT_MOC_LITERAL(14, 139, 20), // "KGpgGroupMemberNode*"
QT_MOC_LITERAL(15, 160, 6), // "member"
QT_MOC_LITERAL(16, 167, 13), // "setDefaultKey"
QT_MOC_LITERAL(17, 181, 12), // "KGpgKeyNode*"
QT_MOC_LITERAL(18, 194, 3), // "def"
QT_MOC_LITERAL(19, 198, 9), // "nodeIndex"
QT_MOC_LITERAL(20, 208, 6), // "column"
QT_MOC_LITERAL(21, 215, 10), // "refreshKey"
QT_MOC_LITERAL(22, 226, 2), // "id"
QT_MOC_LITERAL(23, 229, 2), // "nd"
QT_MOC_LITERAL(24, 232, 11), // "refreshKeys"
QT_MOC_LITERAL(25, 244, 3), // "ids"
QT_MOC_LITERAL(26, 248, 14), // "refreshAllKeys"
QT_MOC_LITERAL(27, 263, 13), // "refreshGroups"
QT_MOC_LITERAL(28, 277, 17), // "invalidateIndexes"
QT_MOC_LITERAL(29, 295, 12), // "refreshTrust"
QT_MOC_LITERAL(30, 308, 22), // "KgpgCore::KgpgKeyTrust"
QT_MOC_LITERAL(31, 331, 5), // "trust"
QT_MOC_LITERAL(32, 337, 5) // "color"

    },
    "KGpgItemModel\0addGroup\0KGpgGroupNode*\0"
    "\0name\0KGpgKeyNode::List\0keys\0delNode\0"
    "KGpgNode*\0node\0changeGroup\0KGpgNode::List\0"
    "deleteFromGroup\0group\0KGpgGroupMemberNode*\0"
    "member\0setDefaultKey\0KGpgKeyNode*\0def\0"
    "nodeIndex\0column\0refreshKey\0id\0nd\0"
    "refreshKeys\0ids\0refreshAllKeys\0"
    "refreshGroups\0invalidateIndexes\0"
    "refreshTrust\0KgpgCore::KgpgKeyTrust\0"
    "trust\0color"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KGpgItemModel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   89,    3, 0x0a /* Public */,
       7,    1,   94,    3, 0x0a /* Public */,
      10,    2,   97,    3, 0x0a /* Public */,
      12,    2,  102,    3, 0x0a /* Public */,
      16,    1,  107,    3, 0x0a /* Public */,
      19,    2,  110,    3, 0x0a /* Public */,
      19,    1,  115,    3, 0x2a /* Public | MethodCloned */,
      21,    1,  118,    3, 0x0a /* Public */,
      21,    1,  121,    3, 0x0a /* Public */,
      24,    1,  124,    3, 0x0a /* Public */,
      24,    1,  127,    3, 0x0a /* Public */,
      26,    0,  130,    3, 0x0a /* Public */,
      27,    0,  131,    3, 0x0a /* Public */,
      28,    1,  132,    3, 0x0a /* Public */,
      29,    2,  135,    3, 0x0a /* Public */,

 // slots: parameters
    0x80000000 | 2, QMetaType::QString, 0x80000000 | 5,    4,    6,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 2, 0x80000000 | 11,    9,    6,
    QMetaType::Void, 0x80000000 | 2, 0x80000000 | 14,   13,   15,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::QModelIndex, 0x80000000 | 8, QMetaType::Int,    9,   20,
    QMetaType::QModelIndex, 0x80000000 | 8,    9,
    QMetaType::Void, QMetaType::QString,   22,
    QMetaType::Void, 0x80000000 | 17,   23,
    QMetaType::Void, QMetaType::QStringList,   25,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 8,   23,
    QMetaType::Void, 0x80000000 | 30, QMetaType::QColor,   31,   32,

       0        // eod
};

void KGpgItemModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KGpgItemModel *_t = static_cast<KGpgItemModel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: { KGpgGroupNode* _r = _t->addGroup((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const KGpgKeyNode::List(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< KGpgGroupNode**>(_a[0]) = std::move(_r); }  break;
        case 1: _t->delNode((*reinterpret_cast< KGpgNode*(*)>(_a[1]))); break;
        case 2: _t->changeGroup((*reinterpret_cast< KGpgGroupNode*(*)>(_a[1])),(*reinterpret_cast< const KGpgNode::List(*)>(_a[2]))); break;
        case 3: _t->deleteFromGroup((*reinterpret_cast< KGpgGroupNode*(*)>(_a[1])),(*reinterpret_cast< KGpgGroupMemberNode*(*)>(_a[2]))); break;
        case 4: _t->setDefaultKey((*reinterpret_cast< KGpgKeyNode*(*)>(_a[1]))); break;
        case 5: { QModelIndex _r = _t->nodeIndex((*reinterpret_cast< KGpgNode*(*)>(_a[1])),(*reinterpret_cast< const int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QModelIndex*>(_a[0]) = std::move(_r); }  break;
        case 6: { QModelIndex _r = _t->nodeIndex((*reinterpret_cast< KGpgNode*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QModelIndex*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->refreshKey((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->refreshKey((*reinterpret_cast< KGpgKeyNode*(*)>(_a[1]))); break;
        case 9: _t->refreshKeys((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 10: _t->refreshKeys((*reinterpret_cast< KGpgKeyNode::List(*)>(_a[1]))); break;
        case 11: _t->refreshAllKeys(); break;
        case 12: _t->refreshGroups(); break;
        case 13: _t->invalidateIndexes((*reinterpret_cast< KGpgNode*(*)>(_a[1]))); break;
        case 14: _t->refreshTrust((*reinterpret_cast< const KgpgCore::KgpgKeyTrust(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KGpgNode* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KGpgKeyNode* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KGpgNode* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KGpgNode* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KGpgKeyNode* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KGpgNode* >(); break;
            }
            break;
        }
    }
}

const QMetaObject KGpgItemModel::staticMetaObject = {
    { &QAbstractItemModel::staticMetaObject, qt_meta_stringdata_KGpgItemModel.data,
      qt_meta_data_KGpgItemModel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KGpgItemModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KGpgItemModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KGpgItemModel.stringdata0))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int KGpgItemModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
