/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -p kgpg_interface /usr/src/extras/kgpg/kgpg-17.12.3-1.x86_64/src/kgpg-17.12.3/org.kde.kgpg.Key.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef KGPG_INTERFACE_H
#define KGPG_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.kgpg.Key
 */
class OrgKdeKgpgKeyInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.kgpg.Key"; }

public:
    OrgKdeKgpgKeyInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeKgpgKeyInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<bool> importRemoteKey(const QString &keyID)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(keyID);
        return asyncCallWithArgumentList(QStringLiteral("importRemoteKey"), argumentList);
    }

    inline QDBusPendingReply<> showKeyInfo(const QString &keyID)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(keyID);
        return asyncCallWithArgumentList(QStringLiteral("showKeyInfo"), argumentList);
    }

    inline QDBusPendingReply<> showKeyManager()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("showKeyManager"), argumentList);
    }

    inline QDBusPendingReply<> showKeyServer()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("showKeyServer"), argumentList);
    }

    inline QDBusPendingReply<> showOptions()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("showOptions"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace kde {
    namespace kgpg {
      typedef ::OrgKdeKgpgKeyInterface Key;
    }
  }
}
#endif
