/****************************************************************************
** Meta object code from reading C++ file 'kgpgoptions.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kgpg-17.12.3/kgpgoptions.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kgpgoptions.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_kgpgOptions_t {
    QByteArrayData data[26];
    char stringdata0[389];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_kgpgOptions_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_kgpgOptions_t qt_meta_stringdata_kgpgOptions = {
    {
QT_MOC_LITERAL(0, 0, 11), // "kgpgOptions"
QT_MOC_LITERAL(1, 12, 13), // "updateDisplay"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 15), // "settingsUpdated"
QT_MOC_LITERAL(4, 43, 10), // "changeFont"
QT_MOC_LITERAL(5, 54, 11), // "homeChanged"
QT_MOC_LITERAL(6, 66, 12), // "refreshTrust"
QT_MOC_LITERAL(7, 79, 22), // "KgpgCore::KgpgKeyTrust"
QT_MOC_LITERAL(8, 102, 14), // "slotChangeHome"
QT_MOC_LITERAL(9, 117, 16), // "slotAddKeyServer"
QT_MOC_LITERAL(10, 134, 19), // "slotChangeEncryptTo"
QT_MOC_LITERAL(11, 154, 16), // "slotDelKeyServer"
QT_MOC_LITERAL(12, 171, 17), // "slotEditKeyServer"
QT_MOC_LITERAL(13, 189, 5), // "index"
QT_MOC_LITERAL(14, 195, 31), // "slotChangeKeyServerButtonEnable"
QT_MOC_LITERAL(15, 227, 20), // "slotDefaultKeyServer"
QT_MOC_LITERAL(16, 248, 13), // "updateWidgets"
QT_MOC_LITERAL(17, 262, 20), // "updateWidgetsDefault"
QT_MOC_LITERAL(18, 283, 14), // "updateSettings"
QT_MOC_LITERAL(19, 298, 8), // "listKeys"
QT_MOC_LITERAL(20, 307, 18), // "slotInstallDecrypt"
QT_MOC_LITERAL(21, 326, 8), // "mimetype"
QT_MOC_LITERAL(22, 335, 15), // "slotInstallSign"
QT_MOC_LITERAL(23, 351, 14), // "slotRemoveMenu"
QT_MOC_LITERAL(24, 366, 4), // "menu"
QT_MOC_LITERAL(25, 371, 17) // "slotSystrayEnable"

    },
    "kgpgOptions\0updateDisplay\0\0settingsUpdated\0"
    "changeFont\0homeChanged\0refreshTrust\0"
    "KgpgCore::KgpgKeyTrust\0slotChangeHome\0"
    "slotAddKeyServer\0slotChangeEncryptTo\0"
    "slotDelKeyServer\0slotEditKeyServer\0"
    "index\0slotChangeKeyServerButtonEnable\0"
    "slotDefaultKeyServer\0updateWidgets\0"
    "updateWidgetsDefault\0updateSettings\0"
    "listKeys\0slotInstallDecrypt\0mimetype\0"
    "slotInstallSign\0slotRemoveMenu\0menu\0"
    "slotSystrayEnable"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_kgpgOptions[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      21,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  119,    2, 0x06 /* Public */,
       3,    0,  120,    2, 0x06 /* Public */,
       4,    1,  121,    2, 0x06 /* Public */,
       5,    0,  124,    2, 0x06 /* Public */,
       6,    2,  125,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    0,  130,    2, 0x08 /* Private */,
       9,    0,  131,    2, 0x08 /* Private */,
      10,    0,  132,    2, 0x08 /* Private */,
      11,    0,  133,    2, 0x08 /* Private */,
      12,    0,  134,    2, 0x08 /* Private */,
      12,    1,  135,    2, 0x08 /* Private */,
      14,    0,  138,    2, 0x08 /* Private */,
      15,    0,  139,    2, 0x08 /* Private */,
      16,    0,  140,    2, 0x08 /* Private */,
      17,    0,  141,    2, 0x08 /* Private */,
      18,    0,  142,    2, 0x08 /* Private */,
      19,    0,  143,    2, 0x08 /* Private */,
      20,    1,  144,    2, 0x08 /* Private */,
      22,    1,  147,    2, 0x08 /* Private */,
      23,    1,  150,    2, 0x08 /* Private */,
      25,    0,  153,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QFont,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 7, QMetaType::QColor,    2,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QModelIndex,   13,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   21,
    QMetaType::Void, QMetaType::QString,   21,
    QMetaType::Void, QMetaType::QString,   24,
    QMetaType::Void,

       0        // eod
};

void kgpgOptions::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        kgpgOptions *_t = static_cast<kgpgOptions *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->updateDisplay(); break;
        case 1: _t->settingsUpdated(); break;
        case 2: _t->changeFont((*reinterpret_cast< QFont(*)>(_a[1]))); break;
        case 3: _t->homeChanged(); break;
        case 4: _t->refreshTrust((*reinterpret_cast< KgpgCore::KgpgKeyTrust(*)>(_a[1])),(*reinterpret_cast< QColor(*)>(_a[2]))); break;
        case 5: _t->slotChangeHome(); break;
        case 6: _t->slotAddKeyServer(); break;
        case 7: _t->slotChangeEncryptTo(); break;
        case 8: _t->slotDelKeyServer(); break;
        case 9: _t->slotEditKeyServer(); break;
        case 10: _t->slotEditKeyServer((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 11: _t->slotChangeKeyServerButtonEnable(); break;
        case 12: _t->slotDefaultKeyServer(); break;
        case 13: _t->updateWidgets(); break;
        case 14: _t->updateWidgetsDefault(); break;
        case 15: _t->updateSettings(); break;
        case 16: _t->listKeys(); break;
        case 17: _t->slotInstallDecrypt((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 18: _t->slotInstallSign((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 19: _t->slotRemoveMenu((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 20: _t->slotSystrayEnable(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (kgpgOptions::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&kgpgOptions::updateDisplay)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (kgpgOptions::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&kgpgOptions::settingsUpdated)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (kgpgOptions::*_t)(QFont );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&kgpgOptions::changeFont)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (kgpgOptions::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&kgpgOptions::homeChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (kgpgOptions::*_t)(KgpgCore::KgpgKeyTrust , QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&kgpgOptions::refreshTrust)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject kgpgOptions::staticMetaObject = {
    { &KConfigDialog::staticMetaObject, qt_meta_stringdata_kgpgOptions.data,
      qt_meta_data_kgpgOptions,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *kgpgOptions::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kgpgOptions::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_kgpgOptions.stringdata0))
        return static_cast<void*>(this);
    return KConfigDialog::qt_metacast(_clname);
}

int kgpgOptions::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void kgpgOptions::updateDisplay()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void kgpgOptions::settingsUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void kgpgOptions::changeFont(QFont _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void kgpgOptions::homeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void kgpgOptions::refreshTrust(KgpgCore::KgpgKeyTrust _t1, QColor _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
